@@ -32,6 +32,8 @@ class ZerohashError(Exception):
         #     return self._messages
 
         # messages = getattr(self._body, "messages", self._messages)
+        if isinstance(self._body, str):
+            return [self._body]
         messages = self._body.get("messages", [])
         if isinstance(messages, str):
             return [messages]
